@@ -419,22 +419,21 @@ class MuseCubeMosaic(CubeMosaic):
         if prefix_cubes is not None:
             self.prefix_cubes = prefix_cubes
 
-        if list_cubes == None:
+        if list_cubes is None:
             # get the list of cubes and return if 0 found
             list_existing_cubes = glob.glob("{0}{1}*.fits".format(self.folder_cubes,
                                                          self.prefix_cubes))
 
-            upipe.print_info("Found {} existing Cubes in this folder".format(
-                len(list_existing_cubes)))
-
-            upipe.print_info("Found {} Cubes after suffix filtering".format(
-                len(list_existing_cubes)))
+            upipe.print_info(f"Found {len(list_existing_cubes)} existing Cubes "
+                             f"in this folder with prefix {self.prefix_cubes}")
 
             # if the list of exclusion suffix is empty, just use all cubes
             list_existing_cubes = filter_list_with_suffix_list(list_existing_cubes,
                                                     self.included_suffix,
                                                     self.excluded_suffix,
                                                     name_list="Existing Cubes")
+            upipe.print_info("Found {} Cubes after suffix filtering".format(
+                len(list_existing_cubes)))
 
             # Filter the list with the pointing dictionary if given
             if self.dict_exposures is not None:
@@ -447,14 +446,14 @@ class MuseCubeMosaic(CubeMosaic):
 
             # Take (or not) the fixed Cubes
             if self.use_fixed_cubes:
-                upipe.print_warning("Using Fixed cubes with prefix {} "
+                upipe.print_warning("Using Corrected cubes with prefix {} "
                                     "when relevant".format(self.prefix_fixed_cubes))
                 prefix_to_consider = "{0}{1}".format(self.prefix_fixed_cubes,
                                                      self.prefix_cubes)
                 list_fixed_cubes = glob.glob("{0}{1}*fits".format(
                                                    self.folder_cubes,
                                                    prefix_to_consider))
-                upipe.print_info("Initial set of {:02d} fixed "
+                upipe.print_info("Initial set of {:02d} Corrected "
                                  "cubes found".format(len(list_fixed_cubes)))
 
                 # if the list of exclusion suffix is empty, just use all cubes
